@@ -118,7 +118,7 @@ else:
 	number = sys.argv[1].split(" ")
 	for n in number: 
 		if not check_number(n):
-			print >> sys.stderr, "Sintax error in USSD number."
+			print >> sys.stderr, "Syntax error in USSD number."
 			sys.exit(-7)
 
 # Parsing command line options
@@ -226,6 +226,7 @@ modem = None
 stage = 0
 if number == "interactive":
 	sys.stdout.write(delimiter)
+	sys.stdout.flush()
 while number == "interactive" or stage < len(number):
 	if modem == None:
 		modem = init_modem(modem)
@@ -236,7 +237,8 @@ while number == "interactive" or stage < len(number):
 			close_modem (modem)
 			sys.exit (0)
 		if not check_number (cnumber):
-			sys.stdout.write ("Sintax error in USSD number"+delimiter)
+			sys.stdout.write ("Syntax error in USSD number"+delimiter)
+			sys.stdout.flush()
 			continue
 	else:
 		cnumber = number[stage]
@@ -302,6 +304,7 @@ while number == "interactive" or stage < len(number):
 	if number == "interactive":
 		# prints line feed
 		sys.stdout.write(reply+delimiter)
+		sys.stdout.flush()
 	else:
 		if stage == len(number)-1:
 			print reply
